@@ -36,6 +36,7 @@
 #' 
 #' @param GBpopdat List. Population data objects returned from modGBpop().
 #' @param p2vegtype String. Type of p2veg estimate ('spp', 'str').
+#' @param peracre Logical. If TRUE, generates per-acre estimates.
 #' @param landarea String. The sample area filter for estimates ("ALL",
 #' "FOREST", "TIMBERLAND").  If landarea=FOREST, filtered to COND_STATUS_CD =
 #' 1; If landarea=TIMBERLAND, filtered to SITECLCD in(1:6) and RESERVCD = 0.
@@ -211,6 +212,7 @@
 #' @export modGBp2veg
 modGBp2veg <- function(GBpopdat = NULL, 
                        p2vegtype = "str", 
+                       peracre = FALSE,
                        landarea = "FOREST", 
                        pcfilter = NULL, 
                        vfilter = NULL, 
@@ -239,7 +241,7 @@ modGBp2veg <- function(GBpopdat = NULL,
   ## If gui.. set variables to NULL
   if (gui) { 
     landarea=strvar=areavar=sumunits=adj=strata=getwt=cuniqueid=ACI=
-      puniqueid=savedata=addtitle=returntitle=rawdata=unitvar <- NULL
+      puniqueid=savedata=addtitle=returntitle=rawdata=unitvar=variable <- NULL
     #if (!row.FIAname) row.FIAname <- NULL
     #if (!col.FIAname) col.FIAname <- NULL
   }
@@ -255,7 +257,7 @@ modGBp2veg <- function(GBpopdat = NULL,
   
   ## Set global variables
   ONEUNIT=n.total=n.strata=strwt=TOTAL=rowvar.filter=colvar.filter=
-    rawfolder <- NULL
+    rawfolder=estvard.name <- NULL
   #estvar <- "CONDPROP_ADJ"
   
   
@@ -375,9 +377,11 @@ modGBp2veg <- function(GBpopdat = NULL,
 
   vcondsppx <- GBpopdat$vcondsppx
   vcondstrx <- GBpopdat$vcondstrx
+  varadjP2VEG <- GBpopdat$varadjP2VEG
   estvar <- "COVER_PCT_SUM"
   vuniqueid <- "PLT_CN"
 
+
   ## Check p2vegtype 
   ########################################################
   p2vegtypelst <- c("str", "spp")
@@ -462,6 +466,7 @@ modGBp2veg <- function(GBpopdat = NULL,
                   title.rowvar=title.rowvar, title.colvar=title.colvar, 
                   rowlut=rowlut, collut=collut, rowgrp=rowgrp, 
                   rowgrpnm=rowgrpnm, rowgrpord=rowgrpord, landarea=landarea)
+  vcondf <- rowcolinfo$treef
   condf <- rowcolinfo$condf
   uniquerow <- rowcolinfo$uniquerow
   uniquecol <- rowcolinfo$uniquecol
@@ -498,27 +503,64 @@ modGBp2veg <- function(GBpopdat = NULL,
                   esttype=esttype, estvarn=estvar, estvarn.TPA=FALSE, 
                   estvarn.filter=vfilter, esttotn=TRUE, 
                   tdomvar=tdomvar, tdomvar2=tdomvar2, adjtree=TRUE, 
-                  adjvar="cadjfac", metric=metric)
+                  adjvar=varadjP2VEG, metric=metric)
   if (is.null(treedat)) return(NULL) 
-
   tdomdat <- treedat$tdomdat
+
   if (rowvar != "TOTAL") {
-    if (!row.add0 && any(tdomdat[[rowvar]] == 0)) {
-      tdomdat <- tdomdat[tdomdat[[rowvar]] != 0,]
+    if (!row.add0) {
+      if (any(is.na(tdomdat[[rowvar]]))) {
+        tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
+      } else if (any(is.na(tdomdat[[rowvar]]))) {
+        tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]),]
+      } else if (any(as.character(tdomdat[[rowvar]]) == "0")) {
+        tdomdat <- tdomdat[tdomdat[[rowvar]] != 0,]
+      }
     }
     if (colvar != "NONE") {
-      if (!col.add0 && any(tdomdat[[colvar]] == 0)) {
-        tdomdat <- tdomdat[tdomdat[[colvar]] != 0,]
+      if (!col.add0) {
+        if (any(is.na(tdomdat[[colvar]]))) {
+          tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
+        } else if (any(is.na(tdomdat[[colvar]]))) {
+          tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]),]
+        } else if (any(as.character(tdomdat[[colvar]]) == "0")) {
+          tdomdat <- tdomdat[tdomdat[[colvar]] != 0,]
+        }
       }
     }
   }
-
+  
+  ## Merge tdomdat with condx
+  xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
+  condx <- xchk$tab1
+  tdomdat <- xchk$tab2
+  
   tdomdat <- merge(condx, tdomdat, by=c(cuniqueid, condid))
-  estvar <- treedat$estvar
-  estvar.name <- treedat$estvar.name
-  estvar.filter <- treedat$estvar.filter
-  tdomvarlst <- treedat$tdomvarlst
-  estunits <- treedat$estunits
+  
+  if (!is.null(tdomvar)) {
+    ## Merge condf with condx
+    xchk <- check.matchclass(condx, condf, c(cuniqueid, condid))
+    condx <- xchk$tab1
+    condf <- xchk$tab2
+    
+    cdomdat <- merge(condx, condf, by=c(cuniqueid, condid))
+  }
+
+  if (peracre) {
+    estvar.filter <- treedat$estvarn.filter
+    tdomvarlst <- treedat$tdomvarlstn
+    estunitsn <- "percent"
+    estvarn.name <- treedat$estvarn.name
+
+    esttype <- "RATIO"
+    estvard.name <- areaunits
+    estunitsd <- areaunits
+  } else {
+    estvar.filter <- treedat$estvar.filter
+    tdomvarlst <- treedat$tdomvarlst
+    estunitsn <- "percent"
+    estvarn.name <- treedat$estvar.name
+  }
 
   ###################################################################################
   ### Get titles for output tables
@@ -551,15 +593,43 @@ modGBp2veg <- function(GBpopdat = NULL,
   addtotal <- ifelse(((rowvar == "TOTAL" || length(unique(tdomdat[[rowvar]])) > 1) ||
 		(!is.null(tdomvarlst) && length(tdomvarlst) > 1)), TRUE, FALSE)
 
+  ## Transpose rows if tdomvar2 is not NULL
+  if (!is.null(tdomvar2)) {
+    ddomvar <- "TOTAL"
+    tdomdat <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+		by=c(strunitvars, cuniqueid, ddomvar), .SDcols=tdomvarlst]
+    tdomdat <- transpose2row(tdomdat, uniqueid=c(strunitvars, cuniqueid, ddomvar),
+ 		tvars=tdomvarlst)
+    setnames(tdomdat, "value", estvarn.name)
+    suppressWarnings(tdomdat[, (grpvar) := tstrsplit(variable, "#")])[, variable := NULL]
+
+    cdomdattot <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+		by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=estvard.name]   
+    tdomdat <- merge(tdomdat, cdomdattot, by=c(strunitvars, cuniqueid, "TOTAL"))
+  }
+
   ## Note: tdomdat is the summed response by condition (not domain)
   #if (addtotal) {
     ## Get estimate for total
-    tdomdattot <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=estvar.name]
-    unit_totest <- GBest.pbar(sumyn=estvar.name, ysum=tdomdattot, 
-                        esttype=esttype, uniqueid=cuniqueid, 
-                        stratalut=stratalut, unitvar=unitvar, strvar=strvar, 
-                        domain="TOTAL")
+    if (!is.null(tdomvar)) {
+      tdomdattot <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                        by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=estvarn.name]
+      cdomdattot <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                        by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=estvard.name]   
+      tdomdattot <- merge(tdomdattot, cdomdattot, by=c(strunitvars, cuniqueid, "TOTAL"))
+    } else {
+      tdomdattot <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                        by=c(strunitvars, cuniqueid, "TOTAL"), .SDcols=c(estvarn.name, estvard.name)]
+    }
+    unit_totest <- GBest.pbar(sumyn = estvarn.name, 
+                              sumyd = estvard.name, 
+                              ysum = tdomdattot, 
+                              esttype = esttype, 
+                              uniqueid = cuniqueid,
+                              stratalut = stratalut, 
+                              unitvar = unitvar, 
+                              strvar = strvar, 
+                              domain = "TOTAL")
     tabs <- check.matchclass(unitarea, unit_totest, unitvar)
     unitarea <- tabs$tab1
     unit_totest <- tabs$tab2
@@ -574,25 +644,123 @@ modGBp2veg <- function(GBpopdat = NULL,
 
   ## Get row, column, cell estimate and merge area if row or column in cond table 
   if (rowvar != "TOTAL") {
-    tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvar.name]
-    tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[rowvar]]),]
-    unit_rowest <- GBest.pbar(sumyn=estvar.name, ysum=tdomdatsum, 
-                          uniqueid=cuniqueid, stratalut=stratalut, 
-                          unitvar=unitvar, strvar=strvar, domain=rowvar)
+    if (!is.null(tdomvar)) {
+      if (!is.null(tdomvar2)) {
+        tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+		          by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvarn.name]    
+      } else {
+        if (tdomvar == rowvar) {
+          tdomdatsum <- transpose2row(tdomdat, uniqueid=c(strunitvars, cuniqueid),
+ 			        tvars=tdomvarlst)
+          setnames(tdomdatsum, c("variable", "value"), c(rowvar, estvarn.name))
+          tdomdatsum <- tdomdatsum[, lapply(.SD, sum, na.rm=TRUE), 
+              by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvarn.name]
+        } else {  
+          tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+              by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvarn.name]
+        }
+      }
+      if (rowvar %in% names(cdomdat)) {
+        cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+            by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvard.name]
+        tdomdatsum <- merge(tdomdatsum, cdomdatsum, 
+                            by=c(strunitvars, cuniqueid, rowvar))
+      } else {
+        cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE),
+            by=c(strunitvars, cuniqueid), .SDcols=estvard.name]
+        tdomdatsum <- merge(tdomdatsum, cdomdatsum, 
+                            by=c(strunitvars, cuniqueid))
+      }
+    } else {
+      tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+		        by=c(strunitvars, cuniqueid, rowvar), .SDcols=c(estvarn.name, estvard.name)]
+    }
+    unit_rowest <- GBest.pbar(sumyn = estvarn.name,
+                              sumyd = estvard.name,  
+                              ysum = tdomdatsum,
+                              esttype = esttype, 
+                              uniqueid = cuniqueid,
+                              stratalut = stratalut, 
+                              unitvar = unitvar, 
+                              strvar = strvar, 
+                              domain = rowvar)
     if (colvar != "NONE") {
-      tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(strunitvars, cuniqueid, colvar), .SDcols=estvar.name]
-      tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[colvar]]),]
-      unit_colest <- GBest.pbar(sumyn=estvar.name, ysum=tdomdatsum, 
-                          uniqueid=cuniqueid, stratalut=stratalut, 
-                          unitvar=unitvar, strvar=strvar, domain=colvar)
+      if (!is.null(tdomvar)) {
+        if (!is.null(tdomvar2)) {
+          tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid, colvar), .SDcols=estvarn.name]    
+        } else {
+          if (tdomvar == colvar) {
+            tdomdatsum <- transpose2row(tdomdat, uniqueid=c(strunitvars, cuniqueid),
+                  tvars=tdomvarlst)
+            setnames(tdomdatsum, c("variable", "value"), c(colvar, estvarn.name))
+            tdomdatsum <- tdomdatsum[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid, colvar), .SDcols=estvarn.name]
+          } else {     
+            tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE),
+                  by=c(strunitvars, cuniqueid, colvar), .SDcols=estvarn.name]
+          }
+        }
+        if (colvar %in% names(cdomdat)) {
+          cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE),
+                  by=c(strunitvars, cuniqueid, colvar), .SDcols=estvard.name]
+          tdomdatsum <- merge(tdomdatsum, cdomdatsum, by=c(strunitvars, cuniqueid, colvar))
+        } else {
+          cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid), .SDcols=estvard.name]
+          tdomdatsum <- merge(tdomdatsum, cdomdatsum, by=c(strunitvars, cuniqueid))
+        }
+      } else {
+        tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid, colvar), .SDcols=c(estvarn.name, estvard.name)]
+      }
+      unit_colest <- GBest.pbar(sumyn = estvarn.name, 
+                                sumyd = estvard.name,  
+                                ysum = tdomdatsum,
+                                esttype = esttype, 
+                                uniqueid = cuniqueid,
+                                stratalut= stratalut,
+                                unitvar = unitvar,
+                                strvar = strvar,
+                                domain = colvar)
 
-      tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-                  by=c(strunitvars, cuniqueid, grpvar), .SDcols=estvar.name]
-      unit_grpest <- GBest.pbar(sumyn=estvar.name, ysum=tdomdatsum, 
-                          uniqueid=cuniqueid, stratalut=stratalut, 
-                          unitvar=unitvar, strvar=strvar, domain=grpvar)
+      if (!is.null(tdomvar)) {
+        if (!is.null(tdomvar2)) {
+          tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+			by=c(strunitvars, cuniqueid, grpvar), .SDcols=c(estvarn.name, estvard.name)]
+        } else {
+          ddomvar <- grpvar[grpvar != tdomvar]
+          tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+              by=c(strunitvars, cuniqueid, ddomvar), .SDcols=tdomvarlst]
+          tdomdatsum <- transpose2row(tdomdatsum, 
+                                      uniqueid=c(strunitvars, cuniqueid, ddomvar), 
+                                      tvars=tdomvarlst)
+          setnames(tdomdatsum, c("variable", "value"), c(tdomvar, estvarn.name))      
+
+          if (any(grpvar %in% names(cdomdat))) {
+            mergevar <- grpvar[grpvar %in% names(cdomdat)]
+            cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid, mergevar), .SDcols=estvard.name]
+            tdomdatsum <- merge(tdomdatsum, cdomdatsum, by=c(strunitvars, cuniqueid, mergevar))
+          } else {
+            cdomdatsum <- cdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+                  by=c(strunitvars, cuniqueid), .SDcols=estvard.name]
+            tdomdatsum <- merge(tdomdatsum, cdomdatsum, by=c(strunitvars, cuniqueid))
+          }
+        }
+      } else {
+        tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
+            by=c(strunitvars, cuniqueid, grpvar), .SDcols=c(estvarn.name, estvard.name)]
+      }
+      unit_grpest <- GBest.pbar(sumyn = estvarn.name, 
+                                sumyd = estvard.name,  
+                                ysum = tdomdatsum, 
+                                esttype = esttype, 
+                                uniqueid = cuniqueid,
+                                stratalut = stratalut, 
+                                unitvar = unitvar, 
+                                strvar = strvar, 
+                                domain = grpvar)
     }
   }
 
@@ -673,10 +841,16 @@ modGBp2veg <- function(GBpopdat = NULL,
 
     ## Calculate unit totals for rowvar
     tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(strunitvars2, vuniqueid, rowvar), .SDcols=estvar.name]
-    rowunit <- GBest.pbar(sumyn=estvar.name, ysum=tdomdatsum, esttype=esttype, 
-			uniqueid=vuniqueid, stratalut=stratalut2, 
-			unitvar="ONEUNIT", strvar=strvar, domain=rowvar)
+		by=c(strunitvars2, vuniqueid, rowvar), .SDcols=estvarn.name]
+    rowunit <- GBest.pbar(sumyn = estvarn.name, 
+                          sumyd = estvard.name, 
+                          ysum = tdomdatsum,
+                          esttype = esttype, 
+                          uniqueid = vuniqueid,
+                          stratalut = stratalut2, 
+                          unitvar = "ONEUNIT",
+                          strvar = strvar, 
+                          domain = rowvar)
 
     rowunit <- add0unit(x=rowunit, xvar=rowvar, uniquex=uniquerow, 
 		unitvar="ONEUNIT", xvar.add0=row.add0)
@@ -694,10 +868,16 @@ modGBp2veg <- function(GBpopdat = NULL,
 
     ## Calculate grand total for all units
     tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(strunitvars2, vuniqueid, "TOTAL"), .SDcols=estvar.name]
-    totunit <- GBest.pbar(sumyn=estvar.name, ysum=tdomdatsum, esttype=esttype, 
-			uniqueid=vuniqueid, stratalut=stratalut2, 
-			unitvar="ONEUNIT", strvar=strvar, domain="TOTAL")
+		by=c(strunitvars2, vuniqueid, "TOTAL"), .SDcols=estvarn.name]
+    totunit <- GBest.pbar(sumyn = estvarn.name,
+                          sumyd = estvard.name, 
+                          ysum = tdomdatsum, 
+                          esttype = esttype, 
+                          uniqueid = vuniqueid,
+                          stratalut = stratalut2, 
+                          unitvar = "ONEUNIT",
+                          strvar = strvar,
+                          domain = "TOTAL")
     tabs <- check.matchclass(unitacres2, totunit, "ONEUNIT")
     unitacres2 <- tabs$tab1
     totunit <- tabs$tab2
@@ -714,7 +894,8 @@ modGBp2veg <- function(GBpopdat = NULL,
   ## GENERATE OUTPUT TABLES
   ###################################################################################
   message("getting output...")
-  estnm <- "est"
+  estnm <- "estn"
+  esttype = "RATIO"
   tabs <- est.outtabs(esttype=esttype, sumunits=sumunits, areavar=areavar, 
                 unitvar=unitvar, unitvars=unitvars, unit_totest=unit_totest, 
                 unit_rowest=unit_rowest, unit_colest=unit_colest, 
@@ -746,7 +927,7 @@ modGBp2veg <- function(GBpopdat = NULL,
   if (rawdata) {
     rawdat <- tabs$rawdat
     rawdat$domdat <- setDF(tdomdat) 
-    rawdat$estvar <- estvar.name
+    rawdat$estvar <- estvarn.name
     rawdat$estvar.filter <- estvar.filter
     if (savedata) {
       if (!is.null(title.estpse)) {
@@ -778,13 +959,14 @@ modGBp2veg <- function(GBpopdat = NULL,
         }
       }
     }
+
     rawdat$esttype <- "P2VEG"
-    rawdat$estvar <- estvar
-    rawdat$estvar.filter <- estvar.filter
+    rawdat$p2vegtype = p2vegtype
+    rawdat$estvar.filter <- vfilter
     if (!is.null(rowvar)) rawdat$rowvar <- rowvar
     if (!is.null(colvar)) rawdat$colvar <- colvar
     rawdat$areaunits <- areaunits
-    rawdat$estunits <- estunits
+    rawdat$estunits <- "percent"
     returnlst$raw <- rawdat
   }
   if (returnGBpopdat) {
