@@ -372,6 +372,7 @@ spGetSAdoms <- function(smallbnd,
   if (any(table(smallbndx[[smallbnd.unique]])) > 1) {
     message("smallbnd.unique is not unique")
   }
+
   ## Apply smallbnd.filter
   ####################################################################
   if (!is.null(smallbnd.filter))  {
@@ -385,7 +386,17 @@ spGetSAdoms <- function(smallbnd,
     smallbnd.unique <- "ONEDOM"
     smallbnd.domain <- "ONEDOM"
   } else {
-   smallbndx <- sf_dissolve(smallbndx, unique(c(smallbnd.unique, smallbnd.domain)))
+    ## Aggregate if smallbnd.domain is different than smallbnd.unique
+    if (smallbnd.domain != smallbnd.unique) {
+      if (length(unique(smallbndx[[smallbnd.domain]])) < length(unique(smallbndx[[smallbnd.unique]]))) {
+        smallbndx <- sf_dissolve(smallbndx, col=smallbnd.domain)
+        smallbnd.unique <- smallbnd.domain
+      } else {
+        smallbndx <- sf_dissolve(smallbndx, unique(c(smallbnd.unique, smallbnd.domain)))
+      }
+    } else {
+      smallbndx <- sf_dissolve(smallbndx, unique(c(smallbnd.unique, smallbnd.domain)))
+    }
   }
  
   ## Apply smallbnd.stfilter (Just state)
@@ -510,7 +521,7 @@ spGetSAdoms <- function(smallbnd,
     largebnd.unique <- pcheck.varchar(var2check=largebnd.unique, 
 		varnm="largebnd.unique", gui=gui, checklst=names(largebndx), 
 		caption="max areas attribute", 
-		warn=paste(largebnd.unique, "not in largebnd"), stopifnull=TRUE)
+		warn=paste(largebnd.unique, "not in largebnd"), stopifnull=FALSE)
   
     ## Apply largebnd.filter
     if (!is.null(largebndx) && !is.null(largebnd.filter)) {
@@ -667,8 +678,9 @@ spGetSAdoms <- function(smallbnd,
   ###########################################################################
   ## Aggregate (dissolve) polygons on DOMAIN and calculate area on dissolved polygons
   ###########################################################################
-  SAdomslst <- lapply(SAdomslst, sf_dissolve, c("DOMAIN", "AOI"))
-  #SAdomslst <- lapply(SAdomslst, sf_dissolve, "DOMAIN")
+  SAcols <- unique(c("DOMAIN", "AOI", largebnd.unique, maxbnd.unique))
+  SAcols <- SAcols[SAcols %in% names(SAdomslst[[1]])]
+  SAdomslst <- lapply(SAdomslst, sf_dissolve, SAcols)
 
   if (showsteps) {
     ## Retain par parameters
@@ -685,6 +697,7 @@ spGetSAdoms <- function(smallbnd,
     if (any(table(SAdomslst[[i]]$DOMAIN) > 1)) {
       stop("check smallbnd.domain.. may not be unique")
     } 
+
     ## Merge other attributes (smallbnd.domain) to SAdoms
     smallbndvars <- unique(c(smallbnd.domain, 
 		names(smallbndxlst[[i]])[!names(smallbndxlst[[i]]) %in% names(SAdomslst[[i]])]))
@@ -698,27 +711,16 @@ spGetSAdoms <- function(smallbnd,
 #		sf::st_drop_geometry(smallbndx[, c(smallbnd.unique, smallbnd.domain)]), 
 #		by.x="DOMAIN", by.y=smallbnd.unique, all.x=TRUE)
 
-    ## Join maxbndx and largebndx attributes (using largest overlap)
-    if (maxislarge && !is.null(maxbndx) && !maxbnd.unique %in% names(SAdomslst[[i]])) {
-      SAdomslst[[i]] <- suppressWarnings(sf::st_join(SAdomslst[[i]], 
-					maxbndx[, maxbnd.unique], largest=TRUE))
-    }
-
-    if (!largeishelper && !is.null(largebndx) && !largebnd.unique %in% names(SAdomslst[[i]])) {
-      SAdomslst[[i]] <- suppressWarnings(sf::st_join(SAdomslst[[i]], 
-					largebndx[, largebnd.unique], largest=TRUE))
-    }
-
+ 
     if (addstate) {
       ## Check projections (reproject largebndx to projection of helperbndx
       prjdat <- crsCompare(SAdomslst[[i]], stunitco, nolonglat=TRUE)
       SAdomslst[[i]] <- prjdat$x
       stunitco <- prjdat$ycrs
-
       SAdomslst[[i]] <- suppressWarnings(sf::st_join(SAdomslst[[i]], 
 					stunitco[, "STATECD"], largest=TRUE))
     }
-
+ 
     if (showsteps) {
       plot(sf::st_geometry(SAdomslst[[i]]), border="dark grey")
       plot(sf::st_geometry(smallbndxlst[[i]]), add=TRUE, border="red", lwd=1, color="translucent")
@@ -730,15 +732,16 @@ spGetSAdoms <- function(smallbnd,
         SAdoms_layer <- paste0(SAdoms_layer, i)
         smallbnd_layer <- paste0(smallbnd_layer, i)
       }
+
       spExportSpatial(SAdomslst[[i]], 
           savedata_opts=list(outfolder=outfolder, 
-                              out_fmt=out_fmt, 
+                              outsp_fmt=outsp_fmt, 
                               out_dsn=out_dsn, 
                               out_layer=SAdoms_layer,
                               outfn.pre=outfn.pre, 
                               outfn.date=outfn.date, 
                               overwrite_layer=overwrite_layer,
-                              append_layer=TRUE, 
+                              append_layer=append_layer, 
                               add_layer=TRUE))
       
       spExportSpatial(smallbndxlst[[i]], 
@@ -749,7 +752,7 @@ spGetSAdoms <- function(smallbnd,
                               outfn.pre=outfn.pre, 
                               outfn.date=outfn.date, 
                               overwrite_layer=overwrite_layer,
-                              append_layer=TRUE, 
+                              append_layer=append_layer, 
                               add_layer=TRUE))
     }
 
